#
# spec file for package rinetd
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1220
%define with_systemd 1
%else
%define with_systemd 0
%endif

Name:           rinetd
Version:        0.62
Release:        26.10
Summary:        TCP Redirection Server
License:        GPL-2.0-or-later
Group:          Productivity/Networking/System
URL:            http://www.boutell.com/rinetd/
Source0:        %{name}-%{version}.tar.bz2
Source1:        rc.rinetd
Source2:        logrotate.rinetd
Source3:        rinetd.service
Patch0:         rinetd-doc.patch
Patch1:         rinetd-syslog.patch
Patch2:         rinetd-conf.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with_systemd}
BuildRequires:  pkgconfig(systemd)
%{?systemd_ordering}
%else
PreReq:         %fillup_prereq %insserv_prereq
%endif

%description
rinetd redirects TCP connections from one IP address and port to
another address and port. rinetd is a single-process server which
handles any number of connections to the address or port pairs
specified in the file /etc/rinetd.conf. Because rinetd runs as a single
process using nonblocking I/O, it is able to redirect a large number of
connections without a severe impact on the machine. This makes it
practical to run TCP services on machines inside an IP masquerading
firewall.

Note: rinetd can not redirect FTP because FTP requires more than one
socket.


%prep
%setup
%patch0
%patch1
%patch2

%build
make CFLAGS="$CFLAGS $RPM_OPT_FLAGS -DLINUX -fno-strict-aliasing"

%install
mkdir -p %{buildroot}/%_mandir/man8
mkdir -p %{buildroot}/%{_sbindir}
%if %{with_systemd}
mkdir -p %{buildroot}%{_unitdir}
install -m 644 %{SOURCE3} %{buildroot}%{_unitdir}/%{name}.service
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rc%{name}
%else
mkdir -p %{buildroot}/etc/init.d
install -m 755 %{SOURCE1} $RPM_BUILD_ROOT/etc/init.d/rinetd
ln -s ../../etc/init.d/rinetd $RPM_BUILD_ROOT/usr/sbin/rcrinetd
%endif
mkdir -p %{buildroot}/etc/logrotate.d
touch $RPM_BUILD_ROOT/etc/rinetd.conf
install -m 700 rinetd %{buildroot}/usr/sbin
install -m 644 rinetd.8 %{buildroot}%_mandir/man8
install -m 644 %SOURCE2 %{buildroot}/etc/logrotate.d/rinetd

%post
%if %{with_systemd}
%service_add_post %{name}.service
%else
%{fillup_and_insserv rinetd}
%endif

%postun
%if %{with_systemd}
%service_del_postun %{name}.service
%else
%{insserv_cleanup}
%endif

%if %{with_systemd}
%pre 
%service_add_pre %{name}.service

%preun
%service_del_preun %{name}.service
%endif

%files
%defattr(-, root, root)
%doc CHANGES README index.html rinetd.conf.sample
%config(missingok,noreplace) %ghost /etc/rinetd.conf
%config(noreplace) /etc/logrotate.d/rinetd
%if %{with_systemd}
%{_unitdir}/%{name}.service
%else
%config /etc/init.d/rinetd
%endif
%_mandir/man8/rinetd.8.gz
/usr/sbin/rcrinetd
/usr/sbin/rinetd

%changelog
* Mon Nov 15 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * rinetd.service
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Fri Jul 18 2014 p.drouand@gmail.com
- Use systemd instead of sysvinit for openSUSE > 12.2
- Clean up spec file
* Fri Nov 12 2010 max@suse.de
- Fix a segfault during shutdown when there is no syslog directive
  in the config file (bnc#651178).
* Tue Sep  8 2009 max@suse.de
- Use version 0.62, obsoleting rinetd-secfix.diff
- Removed Windows binaries from the source tarball.
- Re-add -DLINUX to fix a performance problem (bnc#483381).
- Sanitized naming of patches.
* Wed Jun 17 2009 coolo@novell.com
- fix build
* Thu Aug 28 2008 cthiel@suse.de
- fix init script
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Apr 16 2004 mmj@suse.de
- Don't remove buildroot
- Compile with -fno-strict-aliasing
* Thu Oct 16 2003 mmj@suse.de
- Don't build as root
- Tiny cleanup of specfile
* Mon Aug 25 2003 mmj@suse.de
- add patch for a potential buffer overrun caused by failure to
  reallocate one array when reallocating memory to accommodate
  more than the initially allocated capacity of 64 connections.
* Wed Jan 15 2003 ro@suse.de
- added logrotate config
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Wed Jul 31 2002 mmj@suse.de
- Add %%fillup_and_insserv PreReq
* Sat Jul 27 2002 adrian@suse.de
- do not source rc.config anymore
* Mon Mar  4 2002 mmj@suse.de
- Split rinetd.dif into smaller patches for convienience and
  clarity [BUG #10255]
* Mon Dec 17 2001 grimmer@suse.de
- removed rc.config variable and adjusted init script and spec file
* Thu Apr 19 2001 grimmer@suse.de
- Updated init file according to new skeleton
* Fri Mar  9 2001 grimmer@suse.de
- fixed typo in manpage (#6572)
* Mon Jan  1 2001 olh@suse.de
- use script name in %%post
* Mon Dec 18 2000 grimmer@suse.de
- added Sourceadress extension by Lutz Pressler <lp@SerNet.DE>
* Fri Dec 15 2000 grimmer@suse.de
- init script fixes (added $remote_fs to Required-Start, removed
  run level 2 from Default-Start, added check if binary exists)
* Tue Nov 28 2000 grimmer@suse.de
- moved init script to /etc/init.d and use system facility names
- moved convenience link rcrinetd to /usr/sbin/
* Thu Nov 23 2000 grimmer@suse.de
- extracted init script and rc.config entry from diff
  and added them as separate source files
- added BuildRoot
- created new init script and replaced symbolic links
  with calls to insserv in post and postun section
- corrected fillup error message in post section and expanded
  comment in rc.config
* Wed Feb 16 2000 grimmer@suse.de
- added patch from kus@suse.de to enable logging via syslog
- added Group tag
- added URL
- use manpage macro
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon May 31 1999 grimmer@suse.de
- update to 0.61
* Tue Mar  2 1999 grimmer@suse.de
- new version
- specfile update
* Tue Nov 10 1998 grimmer@suse.de
- new version (0.52)
- new init script (for 6.0)
* Mon Oct  5 1998 grimmer@suse.de
- New Package (version 0.51)
